Crate jismesh
Source - codes
- メッシュコード一覧
- MeshCode
- 地域メッシュコードを表す構造体
- JismeshError
- MeshLevel
- 地域メッシュコードの次数
- to_envelope
- Generate an envelope of mesh codes that cover the rectangular area
defined by the southwest and northeast mesh codes.
- to_intersects
- Generate mesh codes that intersect with the given mesh code at the specified level.
- to_meshcode
- Converts latitude & longitude to a meshcode.
緯度経度から指定次の地域メッシュコードを算出する。
- to_meshlevel
- Determines the mesh level from a meshcode.
- to_meshpoint
- Calculates a mesh point (latitude, longitude) from a meshcode and multipliers.